==> scala-2.2.0.9025.tar.gz: scala/testing/UnitTest.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2003-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: UnitTest.scala 8855 2006-10-05 12:22:34Z michelou $


package scala.testing


/**
 * Some simple methods to support unit testing with assertions
 * to contain more JUnit style assertions which use Scala's features.
 */
object UnitTest {

  class Report(report_ok: () => Unit, report_fail: (String,String) => Unit) {
    def ok: Unit = report_ok()
    def fail(actual: String, expected: String): Unit =
      report_fail(actual, expected)
  }

  var report = new Report(
    { () => Console.println("passed ok") },
    { (actual: String, expected: String) =>
        Console.print("failed! we got")
        Console.print( "\""+ actual +"\"" )
        Console.println(" but expected \"" + expected + "\"") })

  /**
   *  @param r ...
   */
  def setReporter(r: Report) = {
    this.report = r
  }

  /**
   *  @param actual   ...
   *  @param expected ...
   */
  def assertSameElements[a](actual: Seq[a], expected: Seq[a]): Unit =
    if (actual.sameElements(expected))
      report.ok
    else
      report.fail(actual.toString(), expected.toString())

  /**
   *  @param actual   ...
   *  @param expected ...
   */
  def assertEquals[a](actual: a, expected: a): Unit =
    if (actual == expected)
      report.ok
    else
      report.fail(actual.toString(), expected.toString())

  def assertTrue(actual: Boolean): Unit = assertEquals(actual, true)
  def assertFalse(actual: Boolean): Unit = assertEquals(actual, false)

  def assertNotEquals[a]( actual: a, expected: a): Unit =
    if (actual != expected)
      report.ok
    else
      report.fail(actual.toString(), "x != "+expected.toString())

  //def test[a](def doit: a, expected: a): Unit = assertEquals(doit, expected)

} // unitTest

==> scala-2.3.3.tar.gz: scala/testing/UnitTest.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2003-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: UnitTest.scala 9535 2006-12-22 09:13:47Z emir $


package scala.testing


/**
 * Some simple methods to support unit testing with assertions
 * to contain more JUnit style assertions which use Scala's features.
 */
object UnitTest {

  class Report(report_ok: () => Unit, report_fail: (String,String) => Unit) {
    def ok: Unit = report_ok()
    def fail(actual: String, expected: String): Unit =
      report_fail(actual, expected)
  }

  var report = new Report(
    { () => Console.println("passed ok") },
    { (actual: String, expected: String) =>
        Console.print("failed! we got")
        Console.print( "\""+ actual +"\"" )
        Console.println(" but expected \"" + expected + "\"") })

  /**
   *  @param r ...
   */
  def setReporter(r: Report) = {
    this.report = r
  }

  /**
   *  @param actual   ...
   *  @param expected ...
   */
  def assertSameElements[a](actual: Seq[a], expected: Seq[a]): Unit =
    if (actual.sameElements(expected))
      report.ok
    else
      report.fail(actual.toString(), expected.toString())

  /**
   *  @param actual   ...
   *  @param expected ...
   */
  def assertEquals[a](actual: a, expected: a): Unit =
    if (actual == expected)
      report.ok
    else
      report.fail(actual.toString(), expected.toString())

  def assertTrue(actual: Boolean): Unit = assertEquals(actual, true)
  def assertFalse(actual: Boolean): Unit = assertEquals(actual, false)

  def assertNull(actual: AnyRef): Unit = 
   if (actual eq null)
     report.ok
    else
      report.fail(actual.toString, "null")

  def assertNonNull(actual: AnyRef): Unit = 
   if (actual ne null)
     report.ok
    else
      report.fail(actual.toString, "null")
  

  def assertNotEquals[a]( actual: a, expected: a): Unit =
    if (actual != expected)
      report.ok
    else
      report.fail(actual.toString(), "x != "+expected.toString())

  //def test[a](def doit: a, expected: a): Unit = assertEquals(doit, expected)

} // unitTest
